@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 1998-2000, 2008 Sergey Poznyakoff
+   Copyright (C) 1998-2016 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,6 +34,8 @@
 #include <dico/util.h>
 #include <dico/parseopt.h>
 #include <dico/markup.h>
+#include <dico/udb.h>
+#include <dico/tokenize.h>
 
 #endif
     
