@@ -1,5 +1,5 @@
 /* This file is part of GNU Dico.
-   Copyright (C) 2012 Sergey Poznyakoff
+   Copyright (C) 2012-2016 Sergey Poznyakoff
 
    GNU Dico is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -684,7 +684,7 @@ wn_exact_match(struct wndb *db, const char *hw)
 {
     struct result *res;
 
-    if (!wn_is_defined(db, hw))
+    if (!wn_is_defined(db, (char*)hw))
 	return NULL;
     res = wn_create_match_result(db);
     dico_list_append(res->list, strdup(hw));
